from .obs_collection import ObsCollection
from .observation import (
    Obs,
    GroundwaterObs,
    GroundwaterQualityObs,
    PrecipitationObs,
    EvaporationObs,
    MeteoObs,
    ModelObs,
    WaterlvlObs,
)
from .extensions import geo as _geo
from .extensions import gwobs as _gwobs
from .extensions import plots as _plots
from .extensions import stats as _stats
from .version import __version__

import logging

logging.getLogger("hydropandas").addHandler(logging.NullHandler())
